/*

  gofai-wmt configuration module

  Copyright (C) 1999 Laszlo Boloni (boloni@cs.purdue.edu)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  */

#include <qdir.h>
#include <stdio.h>
#include <kconfig.h>
#include <kcmodule.h>

#include <kglobal.h>
#include <klocale.h>

#include "main.h"
#include "main.moc"
#include "LookNFeelConfig.h"
#include "dataview.h"

/**
 *  Factory function. Its functionality is
 *  to create an entry point for the dynamic loader
 */
extern "C"
{
  KCModule *create_kcmgofai(QWidget *parent, const char *name)
  {
    KGlobal::locale()->insertCatalogue("kcmgofai");
    return new GofaiModule(parent, name);
  }
}


GofaiModule::GofaiModule(QWidget *parent, const char *name)
  : KCModule(parent, name)
{

  config = new KConfig("gofairc", false, true);

  QVBoxLayout *layout = new QVBoxLayout(this);
  tab = new QTabWidget(this);
  layout->addWidget(tab);

  dataview = new KDataviewConfig(this, "Dataview");
  dataview->config = config;
  tab->addTab(dataview, i18n("&Dataview"));
  connect(dataview, SIGNAL(changed(bool)),
      this, SLOT(moduleChanged(bool)));

  looknfeel = new LookNFeelConfig(this, "Look & feel");
  looknfeel->config = config;
  tab->addTab(looknfeel, i18n("&Look && feel"));
  connect(looknfeel, SIGNAL(changed(bool)),
          this, SLOT(moduleChanged(bool)));
  load();
}


/**
 *  Loads the configuration info in the two panels.
 */
void GofaiModule::load() {
  dataview->load();
  looknfeel->load();
}


/**
 *  Saves the configuration info by delegating it to
 *  the two panels.
 */
void GofaiModule::save() {
    dataview->save();
    looknfeel->save();
    config->sync();
}


/**
 *  Loads the default configuration in the two
 *  embedded panels.
 */
void GofaiModule::defaults() {
  dataview->defaults();
  looknfeel->defaults();
  emit changed(true);
}


/**
 *  Acts as a relay to transmit the "changed" signal from
 *  the embedded panels to the framework.
 */
void GofaiModule::moduleChanged(bool state)
{
  emit changed(state);
}


/**
 *  Sets the quickhelp text to be displayed in the
 *  help panel of the control framework.
 */
QString GofaiModule::quickHelp() const {
  return i18n("<h1>Configuring GOFAI</h1>"
          "<h2>Data view</h2>"
          "<br><b>Maximum items:</b> "
          "shows how many items can be in "
          "the view at once. Setting it to a convenient level "
          "may help to keep the visual image at a manageable "
          "complexity. At the same time, you should be avare "
          "that for a low value some of the immediate neighbors "
          "may fall out of the view."
          "<h2>Look & Feel</h2>"
          "<br><b>Base font size:</b> "
          "Shows the relative size of the fonts. The fonts will "
          "be scaled anyhow with the size of the window and "
          "the distance from the center "
          "<br><b>Colors:</b> "
          "Sets the colors of the different widgets and the "
          "links with negative or positive weight."
          "<br><b>Animation:</b> "
          "Animated navigation. Turn it of on slow "
          "machines"
          );
}

