/*
    This file is part of the KDE system
    Copyright (C)  1999 Boloni Laszlo

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.

    gofai.h

*/

#ifndef __GOFAI_H
#define __GOFAI_H

#include <kapp.h>
#include <kmainwindow.h>
#include <kmenubar.h>
#include <kurl.h>
#include <kaction.h>
#include <kprocess.h>
#include <qsplitter.h>
// local includes
#include "gofaiWidget.h"
#include "DetailWidget.h"
#include "gofaiDataSource.h"
#include "gofaiDataSource_Memory.h"
#include "gofaiConfig.h"
#include "gofaiEditOntologyDialog.h"
#include "gofaiEditContentTypesDialog.h"
#include "gofaiEditLinkTypesDialog.h"
#include "gofaiStatisticsWindow.h"
#include "gofaiDataQuery.h"

#include "gofai_common.h"

class Gofai : public KMainWindow, public gofai_common {
  Q_OBJECT
public:
  Gofai();
  ~Gofai(){};

  bool loadFile(const QString & filename);
  bool saveToFile(const QString & filename);

  void setupActions();
  void setupStatusBar();
  void restartAutoSave();
/*
  QSplitter *splitter;
  gofaiWidget* gofw;
  DetailWidget* detail;
    // the data view
  gofaiDataView *dv;
*/
  bool queryClose();
  void moveEvent(QMoveEvent *me);

public slots:
  void slotLoadPrevious();
  void slotLoadFile();
  void slotOpenRecent(const KURL &url);
  void slotSaveFile();
  void slotSaveFileAs();
  void slotNew();
  void slotOptions();
  void slotOptionsTerminated(KProcess *process);
  void slotEditOntologies();
  void slotEditContentTypes();
  void slotEditLinkTypes();
  void slotStatistics();
  void slotSetMood();
  void slotToggleToolbar(bool value);
  void slotToggleStatusbar(bool value);
  void slotToggleDetailWindow(bool value);
  void slotToggleMenubar(bool value);
  void slotAutoHide();

protected:
  void showDetailWindow();
  void hideDetailWindow();

private:
    void refresh();

    int statusbarMenuItem, toolbarMenuItem, detailMenuItem, menuMenuItem;
    KToggleAction *showMenubar,
        *showToolbar,
        *showStatusbar,
        *showDetail;
    KRecentFilesAction *recentFiles;
    QTimer *autosaveTimer;
};


#endif //  __GOFAI_H
