/*
    This file is part of the KDE system
    Copyright (C)  1999 Boloni Laszlo

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.


    gofaiConfig.h

    configuration items for GOFAI
 */

#ifndef __GOFAI_CONFIG_H
#define __GOFAI_CONFIG_H

#include <kconfig.h>
#include <kurl.h>
#include "gofaiOntology.h"
#include "gofaiContentType.h"
#include "gofaiLinkType.h"

class gofaiConfig {
 protected:
    gofaiConfig();
 public:
    void saveConfig(KConfig *);
    void loadConfig(KConfig *);
    static gofaiConfig* getInstance();
    // now comes the elements
    // files
    QString defaultfile;
    bool currentFileIsRemote;
    KURL currentRemoteURL;

    int noOldFiles;
    QStringList oldFiles;
    bool autosave;
    int autosaveInterval;

    // ui
    bool toolbarVisible;
    bool statusbarVisible;
    bool detailWindowVisible;
    bool menubarVisible;
    int maxNodesInView;
    int maxLinksInView;
    bool askDelete;
    bool remindsMe;
    double fontbase, fontscale;
    double speedbase, speedscale;
    bool animation;

    QString fontname;
    QColor regular_bg, category_bg;
    QColor positive_link, negative_link;
    bool transparentBg;
    int dragInitDistance;

    // ontologies, types
    QList<gofaiOntology> ontologies;
    gofaiOntology *current_ontology;
    QList<gofaiContentType> content_types;
    gofaiContentType *current_content_type;
    QList<gofaiLinkType> link_types;
    gofaiLinkType *current_link_type;

    // functions
    int getFontSize(int level);
    int getAnimationSpeed();
    void setScale(int w, int h);
 private:
    static gofaiConfig* _instance;
};

#endif
