#include "gofaiDataViewPointer.h"
#include "gofaiDataView.h"
#include "kdebug.h"
#include "stdlib.h"

gofaiDataViewPointer::gofaiDataViewPointer(gofaiDataView *dv) {
    this->dv = dv;
    valid = false;
}

void gofaiDataViewPointer::invalidate() {
  valid = false;
}

void gofaiDataViewPointer::setTo(int index, Place place) {
  valid = true;
  this->place = place;
  this->index = index;
  // this->dv = dv;
};

/**
   Returns the visual item associated with this pointer
 */
gofaiVisualItem* gofaiDataViewPointer::getVisualItem() {
  if (!valid) {
    kdDebug() << "Error: trying to access with an invalid dataview pointer!" << endl;
    exit(2); // punishment
  }
  switch(place) {
  case Main:
    if (index < dv->count) {
      return dv->vds[index];
    } else {
      kdDebug() << "Error: trying to access with index too big in main!" << endl;
      exit(2);
    }
  case Context:
    if (index < dv->context_count) {
      return dv->context_vds[index];
    } else {
      kdDebug() << "Error: trying to access with index too big in context!" << endl;
      exit(2);
    }
  default:
    kdDebug() << "Invalid value for place" << endl;
    exit(2);
  }
  // should never be reached
  return NULL;
}

/**
   Returns the item associated with this pointer
 */
gofaiItem* gofaiDataViewPointer::getItem() {
  return getVisualItem()->val;
};

bool gofaiDataViewPointer::equals(gofaiDataViewPointer &other) {
  return valid == other.valid &&
    place == other.place &&
    index == other.index &&
    dv == other.dv;
}




