/*
    This file is part of the KDE system
    Copyright (C)  1999 Boloni Laszlo

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
/*
 * gofaiFindDialog.cpp
 *
 */

#include "gofaiFindDialog.h"
#include <fstream.h>
#include <qlayout.h>
#include "klocale.h"

gofaiFindDialog::gofaiFindDialog(QWidget *, gofaiDataView *dv) :
    KDialogBase(KDialogBase::Plain,
                "Find node",
                Ok|Cancel,
                Ok
                ) {
    this->dv = dv;
    setButtonOKText("Go");
    QFrame *page = plainPage();
    QVBoxLayout *hlay = new QVBoxLayout(page, 3);

    edt = new KLineEdit(page);
    hlay->addWidget(edt);

    lb = new KListBox(page);
    hlay->addWidget(lb);

    connect( edt, SIGNAL(textChanged(const QString&)), SLOT(refreshList()));
    connect( edt, SIGNAL(returnPressed()), SLOT(accept()));
    connect( lb, SIGNAL(selected(int)), SLOT(accept()) );

    edt->setFocus();
    hlay->activate();
    resize(150,320);
}

void gofaiFindDialog::refreshList() {
    QList<gofaiItem> list;
    dv->getMatchingItems(edt->text(),list);
    QListIterator<gofaiItem> iter(list);
    lb->clear();
    for ( ; iter.current(); ++iter ) {
        gofaiItem *it = iter.current();
        if (it->type==Node)
          lb->insertItem(it->name);
    }
    lb->setCurrentItem(0);
}

QString gofaiFindDialog::getValue() {
    if (lb->numRows() > 0) {
        return lb->text(lb->currentItem());
    }
    return edt->text();
};

#include "gofaiFindDialog.moc"
