/*
    This file is part of the KDE system
    Copyright (C)  1999 Boloni Laszlo

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.

    gofaiItem.h

*/

#include "gofaiItem.h"
#include "gofaiConfig.h"


/**
   gofaiItem constructor
 */
gofaiItem::gofaiItem(QString name, gofaiType type) {
    this->name = name;
    this->type = type;
    created = QDateTime::currentDateTime();
    visited = created;
    confidence = DefaultConfidence;
    strength = DefaultStrength;
    category = false;
    link = "no link for this node";
    /* defaults */
    gofaiConfig *conf = gofaiConfig::getInstance();
    ontology = conf->current_ontology->name;
    content_type = conf->current_content_type->name;
    content_subtype = conf->current_content_type->subname;
}

/**
   Virtual destructor
 */
gofaiItem::~gofaiItem() {
    // empty
}

void gofaiItem::setLinkBetween(gofaiItem *one, gofaiItem *two) {
    from = one->id;
    to = two->id;
};

/**
   Writes out the content of the item into a branch of the
   DOM tree
 */
bool gofaiItem::writeToDOM(QDomDocument &doc, QDomElement &parent) {
        QDomElement e = doc.createElement("item");
        e.setAttribute("id", id);
        e.setAttribute("type", (Q_UINT32)type);
        e.setAttribute("name", name);
        e.setAttribute("link", link);
        e.setAttribute("description", description);
        e.setAttribute("from", from);
        e.setAttribute("to", to);
        // TODO: save data & time
        //      e.setAttribute("created", created);
        //      e.setAttribute("visited", visited);
        e.setAttribute("strength", strength);
        e.setAttribute("confidence", confidence);
        e.setAttribute("category", (int)category);
        e.setAttribute("owner", owner);
        e.setAttribute("ontology", ontology);
        e.setAttribute("content_type", content_type);
        e.setAttribute("content_subtype", content_subtype);
        e.setAttribute("external_data", external_data);
        parent.appendChild(e);

        // now add the custom properties
        QDictIterator<QString> it(properties);

        while ( it.current() ) {
            QString key = it.currentKey();
            QDomElement e2 = doc.createElement(key);
            e2.setAttribute("value", *it.current());
            ++it;
        }
        return true;
}

/**
   Reads the content of the item from a branch of
   the DOM tree
 */
bool gofaiItem::readFromDOM(QDomElement &e) {
  // FIXME: verify the type
  id = e.attribute("id");
  type = (gofaiType)e.attribute("type").toInt();
  name = e.attribute("name");
  link = e.attribute("link");
  description = e.attribute("description");
  from = e.attribute("from");
  to = e.attribute("to");
  // created, visited
  strength = e.attribute("strength").toInt();
  confidence = e.attribute("confidence").toInt();
  category = e.attribute("category").toInt();
  owner = e.attribute("owner");
  ontology = e.attribute("ontology");
  content_type = e.attribute("content_type");
  content_subtype = e.attribute("content_subtype");
  external_data = e.attribute("external_data");

  QDomNode n = e.firstChild();
  while(!n.isNull()) {
      QDomElement e2 = n.toElement();
      QString *val = new QString(e2.attribute("value"));
      properties.insert(e2.tagName(), val);
      n = n.nextSibling();
  }

  return true;
}


/**
   Set the value of the property
 */
void gofaiItem::setProperty(QString name, QString value) {
    properties.insert(name, new QString(value));
}

/**
   Get the value of the property
 */
QString gofaiItem::getProperty(QString name) {
    QString temp = *(properties[name]);
    return temp;
}
