/*
    This file is part of the KDE system
    Copyright (C)  1999,2000 Boloni Laszlo

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.


    gofaiNodeEditor.cpp
*/

#include "gofaiNodeEditor.h"
#include <qlayout.h>
#include <qlabel.h>
#include "klocale.h"

gofaiNodeEditor::gofaiNodeEditor(QWidget *) :
    KDialogBase(KDialogBase::Plain,
                "Edit node",
                Ok|Cancel,
                Ok
                ) {
    changed = false;
    QFrame *page = plainPage();
    QGridLayout *glay = new QGridLayout(page, 0, 0, 10);
    int row=0;
    // name
    QLabel *label;
    name = new KLineEdit(page);
    connect(name, SIGNAL(textChanged(const QString&)),
            this, SLOT(setChanged()));
    glay->addWidget(name, row, 1);
    label = new QLabel(name, i18n("&Name"), page);
    glay->addWidget(label, row, 0);
    row++;
    // link
    link = new KLineEdit(page);
    connect(link, SIGNAL(textChanged(const QString&)),
            this, SLOT(setChanged()));
    link->setMinimumSize(400, link->minimumWidth());
    glay->addWidget(link, row, 1);
    label = new QLabel(link, i18n("&URL"), page);
    glay->addWidget(label, row, 0);
    row++;
    // category
    category = new QCheckBox(page),
    connect(category, SIGNAL(stateChanged(int)),
            this, SLOT(setChanged()));
    glay->addWidget(category, row, 1);
    label = new QLabel(category, "&Category?", page);
    //label->setText(i18n("&Category?"));
    glay->addWidget(label, row,0);
    row++;
    // created
    created = new KLineEdit(page);
    created->setEnabled(false);
    glay->addWidget(created, row, 1);
    label = new QLabel(created, i18n("C&reated"), page);
    glay->addWidget(label, row, 0);
    row++;
    // last visited
    visited = new KLineEdit(page);
    visited->setEnabled(false);
    glay->addWidget(visited, row, 1);
    label = new QLabel(visited, i18n("&Visited"), page);
    glay->addWidget(label, row, 0);
    row++;

    name->setFocus();
    glay->activate();
}

/*
void gofaiNodeEditor::enableOk() {
    ok->setEnabled(true);
}
*/

void gofaiNodeEditor::setChanged() {
    changed = true;
}

void gofaiNodeEditor::setFields(gofaiItem *it) {
        name->setText(it->name);
        link->setText(it->link);
        category->setChecked(it->category);
}

void gofaiNodeEditor::getFields(gofaiItem *it) {
    if (changed) {
        it->name = name->text();
        it->link = link->text();
        it->category = category->isChecked();
    }
}
#include "gofaiNodeEditor.moc"
