/*
    This file is part of the KDE system
    Copyright (C)  1999, 2000 Boloni Laszlo

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.

    gofaiVisualDataStruct.h

   Definition of the main data structure types

*/

#ifndef __GOFAI_VISUAL_DATASTRUCT_H
#define __GOFAI_VISUAL_DATASTRUCT_H

#include <qstring.h>

typedef int COORDINATE;

class gofaiItem;
class gofaiVisualItem;
class gofaiDataView;

class gofaiVisualItemType {
 public:
    gofaiVisualItemType(gofaiVisualItem *vi) {this->vi = vi;};
    virtual void drawIt(QPainter *p, gofaiDataView &dv) = 0;
    virtual bool contains (const QPoint & p,
                           gofaiDataView &dv,
                           bool proper=FALSE ) const = 0;
 protected:
    gofaiVisualItem *vi;
};

class gofaiVisualItemType_Rectangle : public virtual gofaiVisualItemType {
 public:
    gofaiVisualItemType_Rectangle(gofaiVisualItem *vi)
        :gofaiVisualItemType(vi) {};
    void drawIt(QPainter *p, gofaiDataView &dv);
    bool contains (const QPoint & p,
                   gofaiDataView &dv,
                   bool proper=FALSE ) const;
};

class gofaiVisualItemType_Link : public virtual gofaiVisualItemType {
 public:
    gofaiVisualItemType_Link(gofaiVisualItem *vi)
        :gofaiVisualItemType(vi) {};
;
    void drawIt(QPainter *p, gofaiDataView &dv);
    bool contains (const QPoint & p,
                   gofaiDataView &dv,
                   bool proper=FALSE ) const;
};

class gofaiVisualItem {
 public:
    gofaiVisualItem();
    bool newentry, placed;
    int link_count;
    COORDINATE x, y;
    COORDINATE newx, newy, oldx, oldy;
    int level;
    bool shadow;
    gofaiItem *val;
    gofaiVisualItemType *type;
    void moveTo(const QPoint &p);
    void drawIt(QPainter *p, gofaiDataView &dv);
    bool animateIt(QPainter *p, gofaiDataView &dv);
    bool contains (const QPoint & p,
                   gofaiDataView &dv,
                   bool proper=FALSE ) const;
    void setNewPosition();
};

#endif // __GOFAI_VISUAL_DATASTRUCT_H
